<div
    class="modal fade text-dark"
    id="{{ help_id }}"
    tabindex="-1"
    aria-labelledby="exampleModalLabel"
    aria-hidden="true"
>
    <div class="modal-dialog modal-dialog-centered modal-dialog-scrollable modal-lg">
        <div class="modal-content">
            {% if help_title %}
                <div class="modal-header">
                    <h3
                        class="modal-title"
                        id="exampleModalLabel"
                    >
                        {{ help_title }}
                    </h3>
                    <button
                        class="btn-close"
                        type="button"
                        data-bs-dismiss="modal"
                        aria-label="Close"
                    >
                    </button>
                </div>
            {% endif %}
            <div class="modal-body">
                {{ help_content }}
            </div>
            <div class="modal-footer">
                <button
                    class="btn btn-app-secondary"
                    type="button"
                    data-bs-dismiss="modal"
                >
                    Close
                </button>
            </div>
        </div>
    </div>
</div>