{% extends 'spire/authentication/page/authentication_page.html' %}

{% load static %}

{% block base_title %}Password Reset Complete{% endblock %}

{% block authentication_page_content %}
    <h3>Password Reset Complete</h3>
    <div>Your new password has been set. You can log in now on the <a href="{% url 'user_account:authentication:admin:login' %}">log in page</a>.</div>
{% endblock %}