{% extends 'spire/page/form_full_page.html' %}

{% block page_content %}
    <form method="post">
        {% csrf_token %}

        <div class="row g-3">
            <div class="col-12">
                {% include 'placeholder/card/placeholder_form_card.html' %}
            </div>
        </div>
    </form>
{% endblock %}
