{% extends 'spire/authentication/page/authentication_page.html' %}

{% load crispy_forms_filters %}

{% block authentication_page_content %}
    <h5 class="mb-2">Change Password</h5>
    <div>
        <form method="post">
            {% csrf_token %}
            {{ form|crispy }}
            <button type="submit" class="w-100 btn btn-app-primary bg-app-primary mt-2">Submit</button>
        </form>
    </div>
{% endblock %}