<li>
    <button
        :id="$id('tab', which_tab($el.parentElement, $refs.tablist))"
        @click="select($el.id)"
        @focus="select($el.id)"
        type="button"
        role="tab"
        class="bg-transparent h-100 mb-1 position-relative px-3"
        :class="is_selected($el.id) ? 'tab-item text-primary' : 'text-primary-dark' "
        style="border: none;"
    >{{ trigger_title }}</button>
</li>
