{% extends 'spire/modal/modal.html' %}

{% block modal_content %}
    <div class="row justify-content-between pb-1 mb-2 border-bottom">
        <div
            class="col text-uppercase text-app-secondary-dark h6 mb-0"
            {% block modal_title_attributes %}{% endblock %}
        >
            {% block modal_title %}{% endblock %}
        </div>
        <div class="col-auto">
            {% include 'spire/modal/element/model_close_element.html' %}
        </div>
    </div>

    <div class="row">
        <div class="col-12">
            {% block modal_title_content %}
            {% endblock %}
        </div>
    </div>
{% endblock %}
