{% load static %}

<div class="bg-app-side-bar d-block" style="width: 100%; height: 100vh">
    <div class="text-center pt-2">
        {% block side_navigation_top_content %}
            <a class="text-decoration-none mx-auto" href="/">
                <div class="text-center d-flex justify-content-center">
                    {% block side_navigation_img %}
                        <img src="{% static 'img/django_spire.svg' %}" class="w-side-navigation-img" alt="Django Spire Logo">
                    {% endblock %}
                </div>
            </a>
        {% endblock %}
    </div>

    <ul class="nav nav-pills flex-column mt-2 mx-1 p-2">
        {% block side_navigation_links %}
            {% include 'spire/navigation/navigation_links.html' %}
        {% endblock %}
    </ul>
</div>
