{% extends 'spire/authentication/page/authentication_page.html' %}

{% load crispy_forms_filters %}

{% block authentication_page_content %}

    <form method="post" class="text-app-secondary">
        {% csrf_token %}
        {{ form|crispy }}
        <button type="submit" class="d-block mx-auto btn btn-app-primary-outlined my-4 w-100">Login</button>
    </form>

    <div class="text-center">
        <a href="{% url 'authentication:admin:password_reset' %}"
            class="fs--1 text-app-secondary cursor-pointer">
            Forgot my password
        </a>
    </div>

{% endblock %}



