<div
    x-data="{
        async init() {
            await this.placeholder.get()
        },
        placeholder: new GlueModelObject('placeholder')
    }"
>
    {% include 'spire/element/divider_element.html' with divider_title='Details' %}

    <div class="row g-3 mb-3">
        <div class="col-12">
            {% include 'django_glue/form/glue_field/char_field.html' with glue_model_field='placeholder.name' %}
        </div>

        <div class="col-12">
            {% include 'django_glue/form/glue_field/text_field.html' with glue_model_field='placeholder.description' %}
        </div>
    </div>
</div>

{% include 'spire/form/button/form_submit_button.html' %}
