{% extends 'spire/card/title_card.html' %}

{% load core_tags %}

{% block card_title %}
    User List
{% endblock %}

{% block card_button %}
    {% if perms.permission.add_portaluser %}
        {% url 'user_account:register_user_form' as register_user_url %}
        {% include 'spire/button/primary_dark_button.html' with button_text='Add' button_icon='bi bi-plus-lg' button_href=register_user_url %}
    {% endif %}
{% endblock %}

{% block card_title_content %}
    {% for user in user_list %}
        {% include 'spire/user_account/item/user_item.html' %}
    {% empty %}
        {% include 'spire/item/no_data_item.html' %}
    {% endfor %}
{% endblock %}

{% block card_footer %}
    {% include 'spire/element/pagination_element.html' with paginated_list=user_list %}
{% endblock %}
