{% extends 'spire/authentication/page/authentication_page.html' %}

{% load static %}

{% block base_title %}Password Reset Complete{% endblock %}

{% block authentication_page_content %}
    <h3>Password Reset</h3>
    <div>We have sent you an e-mail. Please contact us if you do not receive it within a few minutes.</div>
{% endblock %}